==> chatstore-2.6.12-sources.jar: com/hummer/im/_internals/BeanConversation.java <==
package com.hummer.im._internals;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.hummer.im._internals.shared.CodecManager;
import com.hummer.im.model.Chat;
import com.hummer.im.model.chat.Message;
import com.hummer.im.model.id.IDFactory;
import com.hummer.im.model.id.Identifiable;
import com.j256.ormlite.field.DataType;
import com.j256.ormlite.field.DatabaseField;
import com.j256.ormlite.table.DatabaseTable;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

@SuppressWarnings({"WeakerAccess", "unused"})
@DatabaseTable(tableName = "conversation_indexes")
public class BeanConversation implements Serializable {

    static final String FieldName = "name";
    static final String FieldExtra = "extra";
    static final String FIELD_UNREAD_NUM = "unread_num";
    static final String FIELD_LATEST_MSG = "latest_msg";
    static final String FIELD_TIMESTAMP = "timestamp";
    static final String CODEC_TYPE_NAME = "chat_latest_message";

    @DatabaseField(id = true, columnName = FieldName, unique = true)
    String name;

    @DatabaseField(columnName = FieldExtra)
    String extra;

    /**
     * 未读数
     */
    @DatabaseField(columnName = FIELD_UNREAD_NUM, dataType = DataType.LONG)
    long unreadNum;

    /**
     * 最后一条消息
     */
    @DatabaseField(columnName = FIELD_LATEST_MSG, dataType = DataType.STRING, defaultValue = "")
    String latestMsg;

    /**
     * 时间戳， 用户排序
     */
    @DatabaseField(columnName = FIELD_TIMESTAMP, dataType = DataType.LONG)
    long timestamp;


    public BeanConversation() {
    }

    public BeanConversation(@NonNull String name,
                            @Nullable String extra,
                            long unreadNum,
                            @NonNull String latestMsg,
                            long timestamp) {
        this.name = name;
        this.extra = extra;
        this.unreadNum = unreadNum;
        this.latestMsg = latestMsg;
        this.timestamp = timestamp;
    }

    @Override
    public String toString() {
        return "BeanConversation{" + name + "}";
    }

    static BeanConversation fromConversation(@NonNull Chat chat) {
        BeanConversation index = new BeanConversation();
        index.name  = IDFactory.makeString(chat.getTarget());
        index.extra = chat.getExtra();
        index.unreadNum = chat.getUnreadNum();
        if (chat.getLatestMsg() != null) {
            index.latestMsg = codecs.encode(chat.getLatestMsg());
        } else {
            index.latestMsg = "";
        }
        index.timestamp = chat.getTimestamp();
        return index;
    }

    static Chat toConversation(@NonNull final BeanConversation dbConversation) {
        Identifiable target = IDFactory.makeId(dbConversation.name);
        Message latestMessage = null;
        if (dbConversation.latestMsg != null && dbConversation.latestMsg.length() > 0) {
            latestMessage = codecs.decode(CODEC_TYPE_NAME, dbConversation.latestMsg);
        }
        return new Chat(target,
                dbConversation.extra,
                dbConversation.unreadNum,
                latestMessage,
                dbConversation.timestamp);
    }

    static List<BeanConversation> fromConversations(@NonNull final List<Chat> chats) {
        List<BeanConversation> dbConversations = new ArrayList<>();
        for (Chat c : chats) {
            dbConversations.add(fromConversation(c));
        }

        return dbConversations;
    }

    static List<Chat> toConversations(@NonNull final List<BeanConversation> dbConversations) {
        List<Chat> chats = new ArrayList<>();

        for (BeanConversation c : dbConversations) {
            chats.add(toConversation(c));
        }

        return chats;
    }

    public static final CodecManager<String, String, Message> codecs = new CodecManager<>();
}

==> chatstore-2.11.0-sources.jar: com/hummer/im/_internals/BeanConversation.java <==
package com.hummer.im._internals;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.hummer.im._internals.log.Log;
import com.hummer.im._internals.log.trace.Trace;
import com.hummer.im._internals.shared.CodecManager;
import com.hummer.im.model.Chat;
import com.hummer.im.model.chat.Message;
import com.hummer.im.model.id.IDFactory;
import com.hummer.im.model.id.Identifiable;
import com.j256.ormlite.field.DataType;
import com.j256.ormlite.field.DatabaseField;
import com.j256.ormlite.table.DatabaseTable;

import org.json.JSONArray;
import org.json.JSONException;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;

@SuppressWarnings({"WeakerAccess", "unused"})
@DatabaseTable(tableName = "conversation_indexes")
public class BeanConversation implements Serializable {

    private static final String TAG = "BeanConversation";

    static final String FieldName = "name";
    static final String FieldExtra = "extra";
    static final String FIELD_UNREAD_NUM = "unread_num";
    static final String FIELD_LATEST_MSG = "latest_msg";
    static final String FIELD_TIMESTAMP = "timestamp";
    static final String CODEC_TYPE_NAME = "chat_latest_message";
    static final String FIELD_TAGS = "tags";
    static final String FIELD_PRIORITY = "priority";

    @DatabaseField(id = true, columnName = FieldName, unique = true)
    String name;

    @DatabaseField(columnName = FieldExtra)
    String extra;

    /**
     * 未读数
     */
    @DatabaseField(columnName = FIELD_UNREAD_NUM, dataType = DataType.LONG)
    long unreadNum;

    /**
     * 最后一条消息
     */
    @DatabaseField(columnName = FIELD_LATEST_MSG, dataType = DataType.STRING, defaultValue = "")
    String latestMsg;

    /**
     * 时间戳， 用户排序
     */
    @DatabaseField(columnName = FIELD_TIMESTAMP, dataType = DataType.LONG)
    long timestamp;

    /**
     * 优先级：用于排序。可以实现类似置顶功能
     */
    @DatabaseField(columnName = FIELD_PRIORITY, dataType = DataType.INTEGER)
    int priority;

    /**
     * 标签：陌生人/朋友；目前只支持单个标签。不管以后是否支持多标签，名字先支持
     */
    @DatabaseField(columnName = FIELD_TAGS, dataType = DataType.STRING)
    String tags;


    public BeanConversation() {
    }

    public BeanConversation(@NonNull String name,
                            @Nullable String extra,
                            long unreadNum,
                            @NonNull String latestMsg,
                            long timestamp,
                            int priority,
                            @NonNull String tags) {
        this.name = name;
        this.extra = extra;
        this.unreadNum = unreadNum;
        this.latestMsg = latestMsg;
        this.timestamp = timestamp;
        this.priority = priority;
        this.tags = tags;
    }

    @Override
    public String toString() {
        return "BeanConversation{" + name + "}";
    }

    static BeanConversation fromConversation(@NonNull Chat chat) {
        BeanConversation index = new BeanConversation();
        index.name = IDFactory.makeString(chat.getTarget());
        index.extra = chat.getExtra();
        index.unreadNum = chat.getUnreadNum();
        if (chat.getLatestMsg() != null) {
            index.latestMsg = codecs.encode(chat.getLatestMsg());
        } else {
            index.latestMsg = "";
        }
        index.timestamp = chat.getTimestamp();
        index.priority = chat.getPriority();
        index.tags = new JSONArray(chat.getTags()).toString();

        return index;
    }

    static Chat toConversation(@NonNull final BeanConversation dbConversation) {
        if (dbConversation.name == null) {
            Log.w(TAG, "chat name is null");
            return null;
        }
        Identifiable target = IDFactory.makeId(dbConversation.name);
        Message latestMessage = null;
        if (dbConversation.latestMsg != null && dbConversation.latestMsg.length() > 0) {
            latestMessage = codecs.decode(CODEC_TYPE_NAME, dbConversation.latestMsg);
        }

        JSONArray jsonArray;
        try {
            jsonArray = new JSONArray(dbConversation.tags);
        } catch (JSONException e) {
            Log.e(TAG, Trace.method("toConversation").info("toArray error", e.getMessage()));
            jsonArray = new JSONArray();
        }

        Set<String> tags = new LinkedHashSet<>(jsonArray.length());
        for (int i = 0; i < jsonArray.length(); i++) {
            try {
                tags.add(jsonArray.getString(i));
            } catch (JSONException e) {
                Log.e(TAG, Trace.method("toConversation").info("getString error", e.getMessage()));
            }
        }

        return ChatUtils.newChat(target,
                dbConversation.extra,
                dbConversation.unreadNum,
                latestMessage,
                dbConversation.timestamp,
                dbConversation.priority,
                tags);
    }

    static List<BeanConversation> fromConversations(@NonNull final List<Chat> chats) {
        List<BeanConversation> dbConversations = new ArrayList<>();
        for (Chat c : chats) {
            dbConversations.add(fromConversation(c));
        }

        return dbConversations;
    }

    static List<Chat> toConversations(@NonNull final List<BeanConversation> dbConversations) {
        List<Chat> chats = new ArrayList<>();

        for (BeanConversation c : dbConversations) {
            Chat chat = toConversation(c);
            if (chat != null) {
                chats.add(toConversation(c));
            }
        }

        return chats;
    }

    public static final CodecManager<String, String, Message> codecs = new CodecManager<>();
}
